@@ -1,6 +1,6 @@
 .STRN_fit <- function(par, EmbryoGrowthTRN, tsd, Sexed, Males, Temperatures) {
 
-  infoall <- info.nests(NestsResult=EmbryoGrowthTRN, SexualisationTRN=par, out="summary", sampling = 1)
+  infoall <- info.nests(NestsResult=EmbryoGrowthTRN, SexualisationTRN=par, out="summary", replicate.CI = 1)
 
     temp_TSD <- infoall[, Temperatures]
     
